@@ -163,16 +163,19 @@ class InitialisationStrategy(StrategyBaseClass):
             return wf
 
         elif not len(p) and len(model.substituteModels):
-            wf = Workflow([])
-            for sm in model.substituteModels:
-                wf.append_wf(
-                    sm.initialisationStrategy().workflow(sm),
-                    []
-                )
+            for i, sm in enumerate(model.substituteModels):
+                if i == 0:
+                    wf = sm.initialisationStrategy().workflow(sm)
+                else:
+                    wf.append_wf(
+                        sm.initialisationStrategy().workflow(sm),
+                        []
+                    )
             return wf
 
         else:
-            return Workflow([])
+            return None
+
 
 
 class OutOfBoundsStrategy(StrategyBaseClass):
@@ -431,7 +434,7 @@ class EmptyInitialisationStrategy(InitialisationStrategy):
     """
     @brief    Empty initialisation strategy, used by Forward Mapping Models.
     @details
-              The strategy is used in SurrogateModel.ForwardMappingModel as the
+              The strategy is used in SurrogateModel. ForwardMappingModel as the
               default initialisation strategy. The reason is that the parent
               class requires a surrogate model to implement an initialisation
               strategy.
