@@ -378,7 +378,7 @@ class SurrogateFunction(DynamicDocument):
 
             argPos = kwargs.pop('argPos', False)
             if not argPos:
-                nInp = 0;
+                nInp = 0
                 for k, v in kwargs['inputs'].items():
                     if 'argPos' in v:
                         raise Exception(
@@ -1207,8 +1207,6 @@ class SurrogateModel(DynamicDocument):
         for m in self.substituteModels:
             inputs.update(m.callModel(inputs))
 
-        #print 'inputs', inputs.keys()
-
         # Set inputs
         for k, v in self.inputs.items():
             i[self.inputs_argPos(k)] = inputs[k]
@@ -1230,17 +1228,6 @@ class SurrogateModel(DynamicDocument):
         """
         @brief   Updating parameters of the surrogate model
         """
-        # Load the fitting data
-        # Removed temporarily, probably bug in mongo engine
-
-        #  %%%
-        #  %%%
-        #  %%%
-        # %%%%%
-        #  %%%
-        #   %
-        #if not self["fitData"]:
-        #    self.reload("fitData")
 
         for k, v in self.inputs.items():
             if fw_spec[k][0].__class__ == list:
@@ -1320,8 +1307,6 @@ class SurrogateModel(DynamicDocument):
         for (inp, mmp) in self.outputs.items():
             print(" "*8 + inp + "[ %g, %g ]" %(self.surrogateFunction.outputs[inp]["min"], self.surrogateFunction.outputs[inp]["max"]))
 
-        #print inp + " = " + "[ %.3f, %.3f ]" %(mmp["min"], mmp["max"]) + " \subset " + "[ %g, %g ]" %(self.surrogateFunction.outputs[inp]["min"], self.surrogateFunction.outputs[inp]["max"])
-
 
     @classmethod
     def load(cls, surrogateModelId):
@@ -1431,7 +1416,8 @@ class ForwardMappingModel(SurrogateModel):
                   a detailed model. Consequently, this method should return an
                   empty workflow.
         """
-        return Workflow([])
+        #return Workflow([])
+        return None
 
 
 class BackwardMappingModel(SurrogateModel):
